## -*- coding: utf-8 -*- <%inherit file="/base/base.html"/> <%namespace name="changelog_table" file="changelog_table.html"/> <%block name="title"> ${_('%s Changelog') % c.repo_name} %if c.changelog_for_path: /${c.changelog_for_path} %endif <%def name="breadcrumbs_links()"> <% size = c.size if c.size <= c.total_cs else c.total_cs %> ${_('Changelog')} %if c.changelog_for_path: - /${c.changelog_for_path} %endif %if c.revision: @ ${h.short_id(c.first_revision.raw_id)} %endif - ${ungettext('showing %d out of %d revision', 'showing %d out of %d revisions', size) % (size, c.total_cs)} <%block name="header_menu"> ${self.menu('repositories')} <%def name="main()"> ${self.repo_context_bar('changelog', c.first_revision.raw_id if c.first_revision else None)}
${self.breadcrumbs()}
%if c.cs_pagination:
${h.form(h.url.current(),method='get',class_="form-inline")} ${h.submit(None,_('Show'),id='set_size_submit',class_="btn btn-default btn-sm")} ${h.text('size',size=3,value=c.size,class_='form-control')} ${_('revisions')} %if c.branch_name: ${h.hidden('branch', c.branch_name)} %endif ${_('Clear selection')} ${h.end_form()}
%if c.revision: ${_('Go to tip of repository')} %endif %if c.db_repo.fork: ${_('Compare fork with parent repository (%s)' % c.db_repo.fork.repo_name)} %endif ## text and href of open_new_pr is controlled from javascript ${_("Branch filter:")} ${h.select('branch_filter',c.branch_name,c.branch_filters)}
${changelog_table.changelog(c.repo_name, c.cs_pagination, c.cs_statuses, c.cs_comments, show_checkbox=not c.changelog_for_path, show_branch=not c.branch_name, resize_js='graph.render(jsdata)')}
${c.cs_pagination.pager()}
%else: ${_('There are no changes yet')} %endif